"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.detectProvider = detectProvider;
exports.walkProviders = walkProviders;
var _ci_providers = _interopRequireDefault(require("../ci_providers"));
var _logger = require("../helpers/logger");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function detectProvider(inputs, hasToken = false) {
  const {
    args
  } = inputs;
  let serviceParams;

  //   check if we have a complete set of manual overrides (slug, SHA)
  if (args.sha && (args.slug || hasToken)) {
    // We have the needed args for a manual override
    (0, _logger.info)(`Using manual override from args.`);
    serviceParams = {
      commit: args.sha,
      ...(hasToken ? {} : {
        slug: args.slug
      })
    };
  } else {
    serviceParams = undefined;
  }

  //   loop though all providers
  try {
    const serviceParams = walkProviders(inputs);
    return {
      ...serviceParams,
      ...serviceParams
    };
  } catch (error) {
    //   if fails, display message explaining failure, and explaining that SHA and slug need to be set as args
    if (typeof serviceParams !== 'undefined') {
      (0, _logger.logError)(`Error detecting repos setting using git: ${error}`);
    } else {
      // throw new Error(
      //   '\nUnable to detect SHA and slug, please specify them manually.\nSee the help for more details.',
      // )
    }
  }
  return serviceParams;
}
function walkProviders(inputs) {
  for (const provider of _ci_providers.default) {
    if (provider.detect(inputs.envs)) {
      (0, _logger.info)(`Detected ${provider.getServiceName()} as the CI provider.`);
      _logger.UploadLogger.verbose('-> Using the following env variables:');
      for (const envVarName of provider.getEnvVarNames()) {
        _logger.UploadLogger.verbose(`     ${envVarName}: ${inputs.envs[envVarName]}`);
      }
      return provider.getServiceParams(inputs);
    }
  }
  // 返回默认值
  return {
    slug: '-',
    commit: '-',
    service: '-',
    branch: '-'
    // instrumentCwd: '-',
    // branch: '-',
  };
  // throw new Error(`Unable to detect provider.`)
}